/*
 #include <stdint.h>
#include <stdio.h>
#include <string.h>
#include "nordic_common.h"
#include "nrf_sdm.h"
#include "ble.h"
#include "ble_hci.h"
#include "softdevice_handler.h"
#include "app_error.h"
#include "boards.h"
#include "nrf_gpio.h"
#include "bsp_btn_ble.h"
#include "ble_advdata.h"
#include "nrf_delay.h"
#include "pstorage.h"
//TimeSlot**************************************
#include "nrf_adv_conn.h"
#include "btle.h"
#include "nrf_scan.h"
#include "nrf_assert.h"
//MPU9150**************************************
#include "app_util_platform.h"
#include "app_uart.h"
#include "nrf_drv_twi.h"
#include "nrf_drv_config.h"
#include "bsp.h"
#include "mpu9150.h"
#include "mpu9150_register_map.h"

/*Pins to connect MPU. */
#define MPU9150_TWI_SCL_PIN 1
#define MPU9150_TWI_SDA_PIN 2
#define MPU9150_INT_PIN 		24

accel_values_t acc_values;
volatile static bool INT = false;

//**************************************
//MPU9150***************************************************************************************
static const nrf_drv_twi_t   m_twi_instance = NRF_DRV_TWI_INSTANCE(0);

/**
 * @brief TWI events handler.
 */
//void twi_handler(nrf_drv_twi_evt_t const * p_event, void * p_context)
static void twi_handler(nrf_drv_twi_evt_t * p_event)
{   
    // Pass TWI events down to the MPU driver.
    mpu9150_twi_event_handler(p_event);
}

/**
 * @brief TWI initialization.
 * Just the usual way. Nothing special here
 */
void twi_init(void)
{
    ret_code_t err_code;
    
    const nrf_drv_twi_config_t twi_mpu_9150_config = {
       .scl                = MPU9150_TWI_SCL_PIN,
       .sda                = MPU9150_TWI_SDA_PIN,
       .frequency          = NRF_TWI_FREQ_400K,
       .interrupt_priority = APP_IRQ_PRIORITY_HIGH
    };
    
    err_code = nrf_drv_twi_init(&m_twi_instance, &twi_mpu_9150_config, twi_handler);
    APP_ERROR_CHECK(err_code);
    
    nrf_drv_twi_enable(&m_twi_instance);
}

void mpu_init(void)
{
    ret_code_t ret_code;
    // Initiate MPU9150 driver with TWI instance handler
    ret_code = mpu9150_init(&m_twi_instance);
    APP_ERROR_CHECK(ret_code); // Check for errors in return value
    
    // Setup and configure the MPU9150 with intial values
    mpu9150_config_t p_mpu_config = MPU9150_DEFAULT_CONFIG(); // Load default values
    p_mpu_config.smplrt_div = 19;   // Change sampelrate. Sample Rate = Gyroscope Output Rate / (1 + SMPLRT_DIV). 19 gives a sample rate of 50Hz
    p_mpu_config.accel_config.afs_sel = AFS_2G; // Set accelerometer full scale range to 2G
    ret_code = mpu9150_config(&p_mpu_config); // Configure the MPU9150 with above values
    APP_ERROR_CHECK(ret_code); // Check for errors in return value
    
    // This is a way to configure the interrupt pin behaviour
    mpu9150_int_pin_cfg_t p_int_pin_cfg = MPU9150_DEFAULT_INT_PIN_CONFIG(); // Default configurations
	  //p_int_pin_cfg.latch_int_en = 1; //FA
    p_int_pin_cfg.int_rd_clear = 1; // When this bit is equal to 1, interrupt status bits are cleared on any read operation
    ret_code = mpu9150_int_cfg_pin(&p_int_pin_cfg); // Configure pin behaviour
    APP_ERROR_CHECK(ret_code); // Check for errors in return value
    
    // Enable the MPU interrupts
    mpu9150_int_enable_t p_int_enable = MPU9150_DEFAULT_INT_ENABLE_CONFIG();
    p_int_enable.data_rdy_en = 1; // Trigger interrupt everytime new sensor values are available
    ret_code = mpu9150_int_enable(&p_int_enable); // Configure interrupts
    APP_ERROR_CHECK(ret_code); // Check for errors in return value  
}

//Interrupt from MPU9150**************************************
void int_pin_handler(nrf_drv_gpiote_pin_t pin, nrf_gpiote_polarity_t action)
{
    nrf_gpio_pin_toggle(20);
		INT = true;
		
	  // Read accelerometer sensor values
    //mpu9150_read_accel(&acc_values);
}

/**
 * @brief Function for configuring: PIN_IN pin for input,  
 * and configures GPIOTE to give an interrupt on pin change.
 */
static void gpio_init(void)
{
    ret_code_t err_code;

    err_code = nrf_drv_gpiote_init();
    APP_ERROR_CHECK(err_code);
    
    nrf_drv_gpiote_in_config_t in_config = GPIOTE_CONFIG_IN_SENSE_LOTOHI(true);
    in_config.pull = NRF_GPIO_PIN_PULLDOWN;

    err_code = nrf_drv_gpiote_in_init(MPU9150_INT_PIN, &in_config, int_pin_handler);
    APP_ERROR_CHECK(err_code);

    nrf_drv_gpiote_in_event_enable(MPU9150_INT_PIN, true);
}

static void gpio_blink(uint16_t blk){
		nrf_gpio_pin_toggle(LED_RGB_RED);
		nrf_delay_ms(blk);
		nrf_gpio_pin_toggle(LED_RGB_RED);
		nrf_delay_ms(blk);
}	

//**********************************************************************************************

int main(void)
{
		
		nrf_gpio_cfg_output(0);
		nrf_gpio_pin_set(0);
	
		nrf_gpio_cfg_output(20);
		nrf_gpio_pin_set(20);
	
		nrf_gpio_cfg_output(3);
		nrf_gpio_pin_set(3);
	
		nrf_gpio_cfg_output(21);
		nrf_gpio_pin_set(21);
	
		nrf_gpio_cfg_output(LED_RGB_RED);
		nrf_gpio_pin_set(LED_RGB_RED);
	
		gpio_blink(3000);
		
		nrf_gpio_pin_clear(20);
		nrf_gpio_pin_toggle(LED_RGB_RED);
		
		twi_init();
		gpio_init();
		
		nrf_gpio_pin_set(20);
		nrf_gpio_pin_toggle(LED_RGB_RED);
		
    mpu_init();
		nrf_gpio_pin_clear(20);
					
    for (;; )
    {
			while (!INT);
			if (INT) {
				mpu9150_read_accel(&acc_values);
				INT = false;
			}
      
    }
}


